Dask Internals
==============

This section is intended for contributors and power users who are interested in
learning more about how Dask works internally.

.. toctree::
   :maxdepth: 1

   user-interfaces.rst
   understanding-performance.rst
   phases-of-computation.rst
   order.rst
   caching.rst
   shared.rst
   scheduling-policy.rst
